==> haskell-tidal-1.9.5-2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal
version:              1.9.5
visibility:           public
id:                   tidal-1.9.5-HUvqWaa0H4tFqM3QwCAGsn
key:                  tidal-1.9.5-HUvqWaa0H4tFqM3QwCAGsn
license:              GPL-3.0-only
copyright:            (c) Alex McLean and other contributors, 2021
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding patterns.

category:             Sound
abi:                  23547ef006f12b4b0f3b520e818600c4
exposed:              True
exposed-modules:
    Paths_tidal Sound.Tidal.Bjorklund Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.ID Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Safe.Boot
    Sound.Tidal.Safe.Context Sound.Tidal.Scales Sound.Tidal.Show
    Sound.Tidal.Simple Sound.Tidal.Stream Sound.Tidal.StreamTypes
    Sound.Tidal.Tempo Sound.Tidal.Time Sound.Tidal.Transition
    Sound.Tidal.UI Sound.Tidal.Utils Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tidal-1.9.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tidal-1.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tidal
hs-libraries:         HStidal-1.9.5-HUvqWaa0H4tFqM3QwCAGsn
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    clock-0.8.4-9sRStIU9c0yKwjqfbekeNV
    colour-2.3.6-Lb0j5FHWynL92WxSgZCtF8 containers-0.6.5.1
    deepseq-1.4.6.1 exceptions-0.10.4 hosc-0.20-7IdPlBkWrtA91wrQ61a6AY
    mtl-2.2.2 network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik parsec-3.1.15.0
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4 text-1.2.5.0
    tidal-link-1.0.3-I5U1Wc4P3k4JeOMqGuGeth transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tidal/html/tidal.haddock
haddock-html:         /usr/share/doc/haskell-tidal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tidal-1.9.5-5-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tidal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal
version:              1.9.5
visibility:           public
id:                   tidal-1.9.5-DOuEC7Sh8o3BfNMkYG3AVn
key:                  tidal-1.9.5-DOuEC7Sh8o3BfNMkYG3AVn
license:              GPL-3.0-only
copyright:            (c) Alex McLean and other contributors, 2021
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding patterns.

category:             Sound
abi:                  ada7e9def04e6de1e4995247cfa9f29a
exposed:              True
exposed-modules:
    Paths_tidal Sound.Tidal.Bjorklund Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.ID Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Safe.Boot
    Sound.Tidal.Safe.Context Sound.Tidal.Scales Sound.Tidal.Show
    Sound.Tidal.Simple Sound.Tidal.Stream Sound.Tidal.StreamTypes
    Sound.Tidal.Tempo Sound.Tidal.Time Sound.Tidal.Transition
    Sound.Tidal.UI Sound.Tidal.Utils Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tidal-1.9.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tidal-1.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tidal
hs-libraries:         HStidal-1.9.5-DOuEC7Sh8o3BfNMkYG3AVn
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    clock-0.8.4-2zirxYRTGhh3W19CqzMY2R
    colour-2.3.6-HdI1cmU1Wok1ucyzh0SdSS containers-0.6.5.1
    deepseq-1.4.6.1 exceptions-0.10.4 hosc-0.20-IXsr1a4M41eFEIkD8MOxYb
    mtl-2.2.2 network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ parsec-3.1.15.0
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh text-1.2.5.0
    tidal-link-1.0.3-I5U1Wc4P3k4JeOMqGuGeth transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tidal/html/tidal.haddock
haddock-html:         /usr/share/doc/haskell-tidal/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
